import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { AverageDirectionalIndexIndicator } from "./AverageDirectionalIndexIndicator";
/**
 * Represents a IgxDataChartComponent Average Directional indicator series.
 * Default required members: High, Low, Close
*
* You can use the `AverageDirectionalIndexIndicator` to measures trend strength without regard to trend direction.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrAverageDirectionalIndexIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		volumeMemberPath="Volume"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrAverageDirectionalIndexIndicator();
* series.xAxisName = this.xAxis;
* series.yAxisName = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export class IgrAverageDirectionalIndexIndicator extends IgrStrategyBasedIndicator {
    createImplementation() {
        return new AverageDirectionalIndexIndicator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the moving average period for the current AverageDirectionalIndexIndicator object.
     * The typical, and initial, value for AverageDirectionalIndexIndicator periods is 14.
    *
    * You can use the `Period` to set the moving average.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *     <IgrCategoryXAxis name="xAxis" label="Year" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *     <IgrAverageDirectionalIndexIndicator
    *         name="series1"
    *         xAxisName="xAxis"
    *         yAxisName="yAxis"
    * 		openMemberPath="Open"
    * 		volumeMemberPath="Volume"
    *         highMemberPath="High"
    *         lowMemberPath="Low"
    * 		period="14"/>
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * this.series.period = 14;
    * ```
    */
    get period() {
        return this.i.aav;
    }
    set period(v) {
        this.i.aav = +v;
    }
}
