import { IgrAxis } from "./igr-axis";
import { DataToolTipLayerGroupingMode_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionX_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionY_$type } from "igniteui-react-core";
import { DataAbbreviationMode_$type } from "igniteui-react-core";
import { DataLegendValueMode_$type } from "igniteui-react-core";
import { DataLegendHeaderDateMode_$type } from "igniteui-react-core";
import { DataLegendHeaderTimeMode_$type } from "igniteui-react-core";
import { DataLegendSummaryType_$type } from "igniteui-react-core";
import { LegendItemBadgeShape_$type } from "igniteui-react-core";
import { DataLegendUnitsMode_$type } from "igniteui-react-core";
import { DataLegendLabelMode_$type } from "igniteui-react-core";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { ensureBool, ensureEnum, brushToString, stringToBrush, arrayFindByName } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays grouped tooltips with summaries for series.
*/
export class IgrDataToolTipLayer extends IgrAnnotationLayer {
    createImplementation() {
        return new DataToolTipLayer();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the series is an annotation layer displayed only when hovering over the chart.
    */
    get isAnnotationHoverLayer() {
        return this.i.ec;
    }
    /**
     * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
    */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.en;
    }
    /**
     * Gets or sets the Axis to target this annotation to. If null, this annotation layer will not render content.
    */
    get targetAxis() {
        const r = this.i.yl;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrAxis._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set targetAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.yl = null : this.i.yl = v.i;
    }
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    get useInterpolation() {
        return this.i.z2;
    }
    set useInterpolation(v) {
        this.i.z2 = ensureBool(v);
    }
    /**
     * Gets or sets the grouping mode to apply to use for the tooltip layer.
    */
    get groupingMode() {
        return this.i.y3;
    }
    set groupingMode(v) {
        this.i.y3 = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets the actual resolved tooltip layer grouping mode.
    */
    get actualGroupingMode() {
        return this.i.y2;
    }
    set actualGroupingMode(v) {
        this.i.y2 = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets or sets the offset of the tooltip layer on the X axis.
    */
    get positionOffsetX() {
        return this.i.aab;
    }
    set positionOffsetX(v) {
        this.i.aab = +v;
    }
    /**
     * Gets or sets the offset of the tooltip layer on the Y axis.
    */
    get positionOffsetY() {
        return this.i.aac;
    }
    set positionOffsetY(v) {
        this.i.aac = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the X axis.
    */
    get defaultPositionOffsetX() {
        return this.i.z9;
    }
    set defaultPositionOffsetX(v) {
        this.i.z9 = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the Y axis.
    */
    get defaultPositionOffsetY() {
        return this.i.aaa;
    }
    set defaultPositionOffsetY(v) {
        this.i.aaa = +v;
    }
    /**
     * Gets or sets the tooltip position mode on the X axis for grouped series.
    */
    get groupedPositionModeX() {
        return this.i.yv;
    }
    set groupedPositionModeX(v) {
        this.i.yv = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the X axis for grouped series.
    */
    get actualGroupedPositionModeX() {
        return this.i.yu;
    }
    set actualGroupedPositionModeX(v) {
        this.i.yu = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets or sets the tooltip position mode on the Y axis for grouped series.
    */
    get groupedPositionModeY() {
        return this.i.yz;
    }
    set groupedPositionModeY(v) {
        this.i.yz = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the Y axis for grouped series.
    */
    get actualGroupedPositionModeY() {
        return this.i.yy;
    }
    set actualGroupedPositionModeY(v) {
        this.i.yy = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets or sets whether the data legend should update when the series data is mutated.
    */
    get shouldUpdateWhenSeriesDataChanges() {
        return this.i.z1;
    }
    set shouldUpdateWhenSeriesDataChanges(v) {
        this.i.z1 = ensureBool(v);
    }
    /**
     * Gets or sets indexes, titles, or names of series to include in displaying in the data legend, e.g. "0, 1" or "Series1 Title, Series2 Title"
     * The ExcludedSeries property takes precedence over values of IncludedSeries property
    */
    get includedSeries() {
        return this.i.yi;
    }
    set includedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.yi = v;
    }
    /**
     * Gets or sets indexes, titles, or names of series to exclude from displaying in the data legend, e.g. "0, 1" or "Series1 Title, Series2 Title"
     * The ExcludedSeries property takes precedence over values of IncludedSeries property
    */
    get excludedSeries() {
        return this.i.yd;
    }
    set excludedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.yd = v;
    }
    /**
     * Gets or sets names of data columns or their labels to include in displaying in the data tooltip, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedence over values of IncludedColumns property
    */
    get includedColumns() {
        return this.i.yh;
    }
    set includedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.yh = v;
    }
    /**
     * Gets or sets names of data columns or their labels to exclude from displaying in the data tooltip, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedence over values of IncludedColumns property
    */
    get excludedColumns() {
        return this.i.yc;
    }
    set excludedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.yc = v;
    }
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatAbbreviation() {
        return this.i.ym;
    }
    set valueFormatAbbreviation(v) {
        this.i.ym = ensureEnum(DataAbbreviationMode_$type, v);
    }
    /**
     * Gets or sets maximum digits for formatting numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMaxFractions() {
        return this.i.abb;
    }
    set valueFormatMaxFractions(v) {
        this.i.abb = +v;
    }
    /**
     * Gets or sets minimum digits for formatting numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMinFractions() {
        return this.i.abc;
    }
    set valueFormatMinFractions(v) {
        this.i.abc = +v;
    }
    /**
     * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
    */
    get valueFormatMode() {
        return this.i.ys;
    }
    set valueFormatMode(v) {
        this.i.ys = ensureEnum(DataLegendValueMode_$type, v);
    }
    /**
     * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatCulture() {
        return this.i.adb;
    }
    set valueFormatCulture(v) {
        this.i.adb = v;
    }
    /**
     * Gets or sets whether or not use grouping separator, e.g, 15,000 for 15000
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatUseGrouping() {
        return this.i.z3;
    }
    set valueFormatUseGrouping(v) {
        this.i.z3 = ensureBool(v);
    }
    /**
     * Gets or sets the format string for values displayed in the data legend.
    */
    get valueFormatString() {
        return this.i.adh;
    }
    set valueFormatString(v) {
        this.i.adh = v;
    }
    /**
     * Gets or sets the format specifiers to use with the ValueFormatString string.
    */
    get valueFormatSpecifiers() {
        return this.i.yj;
    }
    set valueFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.yj = v;
    }
    get valueRowMarginBottom() {
        return this.i.agf ? this.i.agf.bottom : NaN;
    }
    set valueRowMarginBottom(v) {
        this.ensureValueRowMargin();
        this.i.agf.bottom = +v;
        this.i.agf = this.i.agf;
    }
    get valueRowMarginLeft() {
        return this.i.agf ? this.i.agf.left : NaN;
    }
    set valueRowMarginLeft(v) {
        this.ensureValueRowMargin();
        this.i.agf.left = +v;
        this.i.agf = this.i.agf;
    }
    get valueRowMarginRight() {
        return this.i.agf ? this.i.agf.right : NaN;
    }
    set valueRowMarginRight(v) {
        this.ensureValueRowMargin();
        this.i.agf.right = +v;
        this.i.agf = this.i.agf;
    }
    get valueRowMarginTop() {
        return this.i.agf ? this.i.agf.top : NaN;
    }
    set valueRowMarginTop(v) {
        this.ensureValueRowMargin();
        this.i.agf.top = +v;
        this.i.agf = this.i.agf;
    }
    ensureValueRowMargin() {
        if (this.i.agf) {
            return;
        }
        this.i.agf = new Thickness(2);
    }
    /**
     * Gets or sets whether to show series rows.
    */
    get valueRowVisible() {
        return this.i.z4;
    }
    set valueRowVisible(v) {
        this.i.z4 = ensureBool(v);
    }
    /**
     * Gets or sets text displayed when data column is missing a value, e.g. "no data"
    */
    get valueTextWhenMissingData() {
        return this.i.adq;
    }
    set valueTextWhenMissingData(v) {
        this.i.adq = v;
    }
    /**
     * Gets or sets whether to use series colors when displaying values in the legend
    */
    get valueTextUseSeriesColors() {
        return this.i.z5;
    }
    set valueTextUseSeriesColors(v) {
        this.i.z5 = ensureBool(v);
    }
    get valueTextMarginBottom() {
        return this.i.agg ? this.i.agg.bottom : NaN;
    }
    set valueTextMarginBottom(v) {
        this.ensureValueTextMargin();
        this.i.agg.bottom = +v;
        this.i.agg = this.i.agg;
    }
    get valueTextMarginLeft() {
        return this.i.agg ? this.i.agg.left : NaN;
    }
    set valueTextMarginLeft(v) {
        this.ensureValueTextMargin();
        this.i.agg.left = +v;
        this.i.agg = this.i.agg;
    }
    get valueTextMarginRight() {
        return this.i.agg ? this.i.agg.right : NaN;
    }
    set valueTextMarginRight(v) {
        this.ensureValueTextMargin();
        this.i.agg.right = +v;
        this.i.agg = this.i.agg;
    }
    get valueTextMarginTop() {
        return this.i.agg ? this.i.agg.top : NaN;
    }
    set valueTextMarginTop(v) {
        this.ensureValueTextMargin();
        this.i.agg.top = +v;
        this.i.agg = this.i.agg;
    }
    ensureValueTextMargin() {
        if (this.i.agg) {
            return;
        }
        this.i.agg = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get valueTextColor() {
        return brushToString(this.i.afy);
    }
    set valueTextColor(v) {
        this.i.afy = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get valueTextStyle() {
        if (this.i.zr == null) {
            return null;
        }
        return this.i.zr.fontString;
    }
    set valueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zr = fi;
    }
    /**
     * Gets or sets the format string for header text displayed in the data legend.
    */
    get headerFormatString() {
        return this.i.abz;
    }
    set headerFormatString(v) {
        this.i.abz = v;
    }
    /**
     * Gets or sets the format specifiers to use with the HeaderFormatString string.
    */
    get headerFormatSpecifiers() {
        return this.i.yg;
    }
    set headerFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.yg = v;
    }
    /**
     * Gets or sets globalization culture when displaying header as date time
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatCulture() {
        return this.i.abv;
    }
    set headerFormatCulture(v) {
        this.i.abv = v;
    }
    /**
     * Gets or sets date format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatDate() {
        return this.i.yn;
    }
    set headerFormatDate(v) {
        this.i.yn = ensureEnum(DataLegendHeaderDateMode_$type, v);
    }
    /**
     * Gets or sets time format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatTime() {
        return this.i.yo;
    }
    set headerFormatTime(v) {
        this.i.yo = ensureEnum(DataLegendHeaderTimeMode_$type, v);
    }
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText() {
        return this.i.ab4;
    }
    set headerText(v) {
        this.i.ab4 = v;
    }
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor() {
        return brushToString(this.i.afq);
    }
    set headerTextColor(v) {
        this.i.afq = stringToBrush(v);
    }
    get headerTextMarginBottom() {
        return this.i.af9 ? this.i.af9.bottom : NaN;
    }
    set headerTextMarginBottom(v) {
        this.ensureHeaderTextMargin();
        this.i.af9.bottom = +v;
        this.i.af9 = this.i.af9;
    }
    get headerTextMarginLeft() {
        return this.i.af9 ? this.i.af9.left : NaN;
    }
    set headerTextMarginLeft(v) {
        this.ensureHeaderTextMargin();
        this.i.af9.left = +v;
        this.i.af9 = this.i.af9;
    }
    get headerTextMarginRight() {
        return this.i.af9 ? this.i.af9.right : NaN;
    }
    set headerTextMarginRight(v) {
        this.ensureHeaderTextMargin();
        this.i.af9.right = +v;
        this.i.af9 = this.i.af9;
    }
    get headerTextMarginTop() {
        return this.i.af9 ? this.i.af9.top : NaN;
    }
    set headerTextMarginTop(v) {
        this.ensureHeaderTextMargin();
        this.i.af9.top = +v;
        this.i.af9 = this.i.af9;
    }
    ensureHeaderTextMargin() {
        if (this.i.af9) {
            return;
        }
        this.i.af9 = new Thickness(2);
    }
    get headerRowMarginBottom() {
        return this.i.af8 ? this.i.af8.bottom : NaN;
    }
    set headerRowMarginBottom(v) {
        this.ensureHeaderRowMargin();
        this.i.af8.bottom = +v;
        this.i.af8 = this.i.af8;
    }
    get headerRowMarginLeft() {
        return this.i.af8 ? this.i.af8.left : NaN;
    }
    set headerRowMarginLeft(v) {
        this.ensureHeaderRowMargin();
        this.i.af8.left = +v;
        this.i.af8 = this.i.af8;
    }
    get headerRowMarginRight() {
        return this.i.af8 ? this.i.af8.right : NaN;
    }
    set headerRowMarginRight(v) {
        this.ensureHeaderRowMargin();
        this.i.af8.right = +v;
        this.i.af8 = this.i.af8;
    }
    get headerRowMarginTop() {
        return this.i.af8 ? this.i.af8.top : NaN;
    }
    set headerRowMarginTop(v) {
        this.ensureHeaderRowMargin();
        this.i.af8.top = +v;
        this.i.af8 = this.i.af8;
    }
    ensureHeaderRowMargin() {
        if (this.i.af8) {
            return;
        }
        this.i.af8 = new Thickness(2);
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get headerRowVisible() {
        return this.i.zu;
    }
    set headerRowVisible(v) {
        this.i.zu = ensureBool(v);
    }
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextStyle() {
        if (this.i.zj == null) {
            return null;
        }
        return this.i.zj.fontString;
    }
    set headerTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zj = fi;
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get groupRowVisible() {
        return this.i.zt;
    }
    set groupRowVisible(v) {
        this.i.zt = ensureBool(v);
    }
    /**
     * Gets or sets the Group text color.
    */
    get groupTextColor() {
        return brushToString(this.i.afp);
    }
    set groupTextColor(v) {
        this.i.afp = stringToBrush(v);
    }
    get groupTextMarginBottom() {
        return this.i.af7 ? this.i.af7.bottom : NaN;
    }
    set groupTextMarginBottom(v) {
        this.ensureGroupTextMargin();
        this.i.af7.bottom = +v;
        this.i.af7 = this.i.af7;
    }
    get groupTextMarginLeft() {
        return this.i.af7 ? this.i.af7.left : NaN;
    }
    set groupTextMarginLeft(v) {
        this.ensureGroupTextMargin();
        this.i.af7.left = +v;
        this.i.af7 = this.i.af7;
    }
    get groupTextMarginRight() {
        return this.i.af7 ? this.i.af7.right : NaN;
    }
    set groupTextMarginRight(v) {
        this.ensureGroupTextMargin();
        this.i.af7.right = +v;
        this.i.af7 = this.i.af7;
    }
    get groupTextMarginTop() {
        return this.i.af7 ? this.i.af7.top : NaN;
    }
    set groupTextMarginTop(v) {
        this.ensureGroupTextMargin();
        this.i.af7.top = +v;
        this.i.af7 = this.i.af7;
    }
    ensureGroupTextMargin() {
        if (this.i.af7) {
            return;
        }
        this.i.af7 = new Thickness(2);
    }
    get groupRowMarginBottom() {
        return this.i.af6 ? this.i.af6.bottom : NaN;
    }
    set groupRowMarginBottom(v) {
        this.ensureGroupRowMargin();
        this.i.af6.bottom = +v;
        this.i.af6 = this.i.af6;
    }
    get groupRowMarginLeft() {
        return this.i.af6 ? this.i.af6.left : NaN;
    }
    set groupRowMarginLeft(v) {
        this.ensureGroupRowMargin();
        this.i.af6.left = +v;
        this.i.af6 = this.i.af6;
    }
    get groupRowMarginRight() {
        return this.i.af6 ? this.i.af6.right : NaN;
    }
    set groupRowMarginRight(v) {
        this.ensureGroupRowMargin();
        this.i.af6.right = +v;
        this.i.af6 = this.i.af6;
    }
    get groupRowMarginTop() {
        return this.i.af6 ? this.i.af6.top : NaN;
    }
    set groupRowMarginTop(v) {
        this.ensureGroupRowMargin();
        this.i.af6.top = +v;
        this.i.af6 = this.i.af6;
    }
    ensureGroupRowMargin() {
        if (this.i.af6) {
            return;
        }
        this.i.af6 = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the Group text.
    */
    get groupTextStyle() {
        if (this.i.zi == null) {
            return null;
        }
        return this.i.zi.fontString;
    }
    set groupTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zi = fi;
    }
    /**
     * Gets or sets the summary text color.
    */
    get summaryTitleTextColor() {
        return brushToString(this.i.aft);
    }
    set summaryTitleTextColor(v) {
        this.i.aft = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTitleTextStyle() {
        if (this.i.zm == null) {
            return null;
        }
        return this.i.zm.fontString;
    }
    set summaryTitleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zm = fi;
    }
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType() {
        return this.i.yq;
    }
    set summaryType(v) {
        this.i.yq = ensureEnum(DataLegendSummaryType_$type, v);
    }
    /**
     * Gets or sets the SummaryTitleText for the data legend.
    */
    get summaryTitleText() {
        return this.i.acn;
    }
    set summaryTitleText(v) {
        this.i.acn = v;
    }
    get summaryTitleTextMarginBottom() {
        return this.i.agc ? this.i.agc.bottom : NaN;
    }
    set summaryTitleTextMarginBottom(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.agc.bottom = +v;
        this.i.agc = this.i.agc;
    }
    get summaryTitleTextMarginLeft() {
        return this.i.agc ? this.i.agc.left : NaN;
    }
    set summaryTitleTextMarginLeft(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.agc.left = +v;
        this.i.agc = this.i.agc;
    }
    get summaryTitleTextMarginRight() {
        return this.i.agc ? this.i.agc.right : NaN;
    }
    set summaryTitleTextMarginRight(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.agc.right = +v;
        this.i.agc = this.i.agc;
    }
    get summaryTitleTextMarginTop() {
        return this.i.agc ? this.i.agc.top : NaN;
    }
    set summaryTitleTextMarginTop(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.agc.top = +v;
        this.i.agc = this.i.agc;
    }
    ensureSummaryTitleTextMargin() {
        if (this.i.agc) {
            return;
        }
        this.i.agc = new Thickness(2);
    }
    get summaryRowMarginBottom() {
        return this.i.agb ? this.i.agb.bottom : NaN;
    }
    set summaryRowMarginBottom(v) {
        this.ensureSummaryRowMargin();
        this.i.agb.bottom = +v;
        this.i.agb = this.i.agb;
    }
    get summaryRowMarginLeft() {
        return this.i.agb ? this.i.agb.left : NaN;
    }
    set summaryRowMarginLeft(v) {
        this.ensureSummaryRowMargin();
        this.i.agb.left = +v;
        this.i.agb = this.i.agb;
    }
    get summaryRowMarginRight() {
        return this.i.agb ? this.i.agb.right : NaN;
    }
    set summaryRowMarginRight(v) {
        this.ensureSummaryRowMargin();
        this.i.agb.right = +v;
        this.i.agb = this.i.agb;
    }
    get summaryRowMarginTop() {
        return this.i.agb ? this.i.agb.top : NaN;
    }
    set summaryRowMarginTop(v) {
        this.ensureSummaryRowMargin();
        this.i.agb.top = +v;
        this.i.agb = this.i.agb;
    }
    ensureSummaryRowMargin() {
        if (this.i.agb) {
            return;
        }
        this.i.agb = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryValueTextColor() {
        return brushToString(this.i.afv);
    }
    set summaryValueTextColor(v) {
        this.i.afv = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryValueTextStyle() {
        if (this.i.zo == null) {
            return null;
        }
        return this.i.zo.fontString;
    }
    set summaryValueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zo = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryLabelText() {
        return this.i.aci;
    }
    set summaryLabelText(v) {
        this.i.aci = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryLabelTextColor() {
        return brushToString(this.i.afs);
    }
    set summaryLabelTextColor(v) {
        this.i.afs = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryLabelTextStyle() {
        if (this.i.zl == null) {
            return null;
        }
        return this.i.zl.fontString;
    }
    set summaryLabelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zl = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryUnitsText() {
        return this.i.act;
    }
    set summaryUnitsText(v) {
        this.i.act = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryUnitsTextColor() {
        return brushToString(this.i.afu);
    }
    set summaryUnitsTextColor(v) {
        this.i.afu = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryUnitsTextStyle() {
        if (this.i.zn == null) {
            return null;
        }
        return this.i.zn.fontString;
    }
    set summaryUnitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zn = fi;
    }
    get badgeMarginBottom() {
        return this.i.af5 ? this.i.af5.bottom : NaN;
    }
    set badgeMarginBottom(v) {
        this.ensureBadgeMargin();
        this.i.af5.bottom = +v;
        this.i.af5 = this.i.af5;
    }
    get badgeMarginLeft() {
        return this.i.af5 ? this.i.af5.left : NaN;
    }
    set badgeMarginLeft(v) {
        this.ensureBadgeMargin();
        this.i.af5.left = +v;
        this.i.af5 = this.i.af5;
    }
    get badgeMarginRight() {
        return this.i.af5 ? this.i.af5.right : NaN;
    }
    set badgeMarginRight(v) {
        this.ensureBadgeMargin();
        this.i.af5.right = +v;
        this.i.af5 = this.i.af5;
    }
    get badgeMarginTop() {
        return this.i.af5 ? this.i.af5.top : NaN;
    }
    set badgeMarginTop(v) {
        this.ensureBadgeMargin();
        this.i.af5.top = +v;
        this.i.af5 = this.i.af5;
    }
    ensureBadgeMargin() {
        if (this.i.af5) {
            return;
        }
        this.i.af5 = new Thickness(2);
    }
    /**
     * Gets or sets the BadgeShape for the data legend.
    */
    get badgeShape() {
        return this.i.y7;
    }
    set badgeShape(v) {
        this.i.y7 = ensureEnum(LegendItemBadgeShape_$type, v);
    }
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get unitsDisplayMode() {
        return this.i.yr;
    }
    set unitsDisplayMode(v) {
        this.i.yr = ensureEnum(DataLegendUnitsMode_$type, v);
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get unitsText() {
        return this.i.ac4;
    }
    set unitsText(v) {
        this.i.ac4 = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get unitsTextColor() {
        return brushToString(this.i.afx);
    }
    set unitsTextColor(v) {
        this.i.afx = stringToBrush(v);
    }
    get unitsTextMarginBottom() {
        return this.i.age ? this.i.age.bottom : NaN;
    }
    set unitsTextMarginBottom(v) {
        this.ensureUnitsTextMargin();
        this.i.age.bottom = +v;
        this.i.age = this.i.age;
    }
    get unitsTextMarginLeft() {
        return this.i.age ? this.i.age.left : NaN;
    }
    set unitsTextMarginLeft(v) {
        this.ensureUnitsTextMargin();
        this.i.age.left = +v;
        this.i.age = this.i.age;
    }
    get unitsTextMarginRight() {
        return this.i.age ? this.i.age.right : NaN;
    }
    set unitsTextMarginRight(v) {
        this.ensureUnitsTextMargin();
        this.i.age.right = +v;
        this.i.age = this.i.age;
    }
    get unitsTextMarginTop() {
        return this.i.age ? this.i.age.top : NaN;
    }
    set unitsTextMarginTop(v) {
        this.ensureUnitsTextMargin();
        this.i.age.top = +v;
        this.i.age = this.i.age;
    }
    ensureUnitsTextMargin() {
        if (this.i.age) {
            return;
        }
        this.i.age = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get unitsTextStyle() {
        if (this.i.zq == null) {
            return null;
        }
        return this.i.zq.fontString;
    }
    set unitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zq = fi;
    }
    get titleTextMarginBottom() {
        return this.i.agd ? this.i.agd.bottom : NaN;
    }
    set titleTextMarginBottom(v) {
        this.ensureTitleTextMargin();
        this.i.agd.bottom = +v;
        this.i.agd = this.i.agd;
    }
    get titleTextMarginLeft() {
        return this.i.agd ? this.i.agd.left : NaN;
    }
    set titleTextMarginLeft(v) {
        this.ensureTitleTextMargin();
        this.i.agd.left = +v;
        this.i.agd = this.i.agd;
    }
    get titleTextMarginRight() {
        return this.i.agd ? this.i.agd.right : NaN;
    }
    set titleTextMarginRight(v) {
        this.ensureTitleTextMargin();
        this.i.agd.right = +v;
        this.i.agd = this.i.agd;
    }
    get titleTextMarginTop() {
        return this.i.agd ? this.i.agd.top : NaN;
    }
    set titleTextMarginTop(v) {
        this.ensureTitleTextMargin();
        this.i.agd.top = +v;
        this.i.agd = this.i.agd;
    }
    ensureTitleTextMargin() {
        if (this.i.agd) {
            return;
        }
        this.i.agd = new Thickness(2);
    }
    /**
     * Gets or sets the display text color.
    */
    get titleTextColor() {
        return brushToString(this.i.afw);
    }
    set titleTextColor(v) {
        this.i.afw = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the display text.
    */
    get titleTextStyle() {
        if (this.i.zp == null) {
            return null;
        }
        return this.i.zp.fontString;
    }
    set titleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zp = fi;
    }
    /**
     * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
    */
    get labelDisplayMode() {
        return this.i.yp;
    }
    set labelDisplayMode(v) {
        this.i.yp = ensureEnum(DataLegendLabelMode_$type, v);
    }
    /**
     * Gets or sets the units text color.
    */
    get labelTextColor() {
        return brushToString(this.i.afr);
    }
    set labelTextColor(v) {
        this.i.afr = stringToBrush(v);
    }
    get labelTextMarginBottom() {
        return this.i.aga ? this.i.aga.bottom : NaN;
    }
    set labelTextMarginBottom(v) {
        this.ensureLabelTextMargin();
        this.i.aga.bottom = +v;
        this.i.aga = this.i.aga;
    }
    get labelTextMarginLeft() {
        return this.i.aga ? this.i.aga.left : NaN;
    }
    set labelTextMarginLeft(v) {
        this.ensureLabelTextMargin();
        this.i.aga.left = +v;
        this.i.aga = this.i.aga;
    }
    get labelTextMarginRight() {
        return this.i.aga ? this.i.aga.right : NaN;
    }
    set labelTextMarginRight(v) {
        this.ensureLabelTextMargin();
        this.i.aga.right = +v;
        this.i.aga = this.i.aga;
    }
    get labelTextMarginTop() {
        return this.i.aga ? this.i.aga.top : NaN;
    }
    set labelTextMarginTop(v) {
        this.ensureLabelTextMargin();
        this.i.aga.top = +v;
        this.i.aga = this.i.aga;
    }
    ensureLabelTextMargin() {
        if (this.i.aga) {
            return;
        }
        this.i.aga = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get labelTextStyle() {
        if (this.i.zk == null) {
            return null;
        }
        return this.i.zk.fontString;
    }
    set labelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.zk = fi;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetAxis && this.targetAxis.name && this.targetAxis.name == name) {
            return this.targetAxis;
        }
        if (this.valueFormatSpecifiers != null && arrayFindByName(this.valueFormatSpecifiers, name)) {
            return arrayFindByName(this.valueFormatSpecifiers, name);
        }
        if (this.headerFormatSpecifiers != null && arrayFindByName(this.headerFormatSpecifiers, name)) {
            return arrayFindByName(this.headerFormatSpecifiers, name);
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.targetAxis && this.targetAxis._styling) {
            this.targetAxis._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTips() {
        this.i.o3();
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTipsImmediate() {
        this.i.o4();
    }
}
