import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.vz;
        },
        set: function (v) {
            this.i.vz = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.v0;
        },
        set: function (v) {
            this.i.v0 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.ya);
        },
        set: function (v) {
            this.i.ya = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.vu;
        },
        set: function (v) {
            this.i.vu = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.em;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.vg;
        },
        set: function (v) {
            this.i.vg = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.vd;
        },
        set: function (v) {
            this.i.vd = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.wd;
        },
        set: function (v) {
            this.i.wd = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.v2;
        },
        set: function (v) {
            this.i.v2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.vn;
        },
        set: function (v) {
            this.i.vn = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ve;
        },
        set: function (v) {
            this.i.ve = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.vo;
        },
        set: function (v) {
            this.i.vo = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.vf;
        },
        set: function (v) {
            this.i.vf = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.wc;
        },
        set: function (v) {
            this.i.wc = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.v1;
        },
        set: function (v) {
            this.i.v1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.we;
        },
        set: function (v) {
            this.i.we = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.v3;
        },
        set: function (v) {
            this.i.v3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.x7);
        },
        set: function (v) {
            this.i.x7 = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.x1);
        },
        set: function (v) {
            this.i.x1 = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.x8);
        },
        set: function (v) {
            this.i.x8 = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.x2);
        },
        set: function (v) {
            this.i.x2 = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.e1;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.ed;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.vy;
        },
        set: function (v) {
            this.i.vy = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };
