import { __extends } from "tslib";
import { ValueLayerValueMode_$type } from "./ValueLayerValueMode";
import { IgrSeries } from "./igr-series";
import { IgrAxis } from "./igr-axis";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { ValueLayer } from "./ValueLayer";
import { ensureBool, ensureEnum, brushToString, stringToBrush } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
var IgrValueLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrValueLayer, _super);
    function IgrValueLayer(props) {
        return _super.call(this, props) || this;
    }
    IgrValueLayer.prototype.createImplementation = function () {
        return new ValueLayer();
    };
    Object.defineProperty(IgrValueLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "isAnnotationValueLayer", {
        /**
         * Gets whether the series is an crosshair annotation layer.
        */
        get: function () {
            return this.i.ee;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "valueMode", {
        /**
         * Gets or sets the value mode for the overlay.
        */
        get: function () {
            return this.i.yh;
        },
        set: function (v) {
            this.i.yh = ensureEnum(ValueLayerValueMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "horizontalLineStroke", {
        /**
         * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
        */
        get: function () {
            return brushToString(this.i.aa5);
        },
        set: function (v) {
            this.i.aa5 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "verticalLineStroke", {
        /**
         * Gets or sets the color to use for vertical line. Leave null for an automatic value.
        */
        get: function () {
            return brushToString(this.i.aa6);
        },
        set: function (v) {
            this.i.aa6 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "targetSeriesName", {
        /**
         * Gets or sets the name of the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            return this.i.za;
        },
        set: function (v) {
            this.i.za = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            var r = this.i.yf;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.yf = null : this.i.yf = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "targetAxisName", {
        /**
         * Gets or sets the name of the axis to target this annotation to. If null, this annotation targets all axis simultaneously.
        */
        get: function () {
            return this.i.y7;
        },
        set: function (v) {
            this.i.y7 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "targetAxis", {
        /**
         * Gets or sets the axis to target this annotation to. If null, this annotation targets all value axis simultaneously.
        */
        get: function () {
            var r = this.i.yc;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrAxis._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.yc = null : this.i.yc = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
        get: function () {
            return this.i.ym;
        },
        set: function (v) {
            this.i.ym = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "isAxisAnnotationEnabled", {
        /**
         * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
        */
        get: function () {
            return this.i.yj;
        },
        set: function (v) {
            this.i.yj = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationFormatLabel", {
        /**
         * Sets or gets a function which takes an object that produces a formatted label for the x axis annotation.
        */
        get: function () {
            return this.i.yd;
        },
        set: function (v) {
            this.i.yd = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationFormatLabel", {
        /**
         * Sets or gets a function which takes an object that produces a formatted label for the y axis annotation.
        */
        get: function () {
            return this.i.ye;
        },
        set: function (v) {
            this.i.ye = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.aa9);
        },
        set: function (v) {
            this.i.aa9 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.aa7);
        },
        set: function (v) {
            this.i.aa7 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationBackgroundCornerRadius", {
        /**
         * Gets or sets the corner radius to use for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.yp;
        },
        set: function (v) {
            this.i.yp = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: function () {
            return this.i.y1;
        },
        set: function (v) {
            this.i.y1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.aa8);
        },
        set: function (v) {
            this.i.aa8 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationPaddingLeft", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yr;
        },
        set: function (v) {
            this.i.yr = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationPaddingTop", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yt;
        },
        set: function (v) {
            this.i.yt = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationPaddingRight", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.ys;
        },
        set: function (v) {
            this.i.ys = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationPaddingBottom", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yq;
        },
        set: function (v) {
            this.i.yq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationPaddingLeft", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yx;
        },
        set: function (v) {
            this.i.yx = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationPaddingTop", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yz;
        },
        set: function (v) {
            this.i.yz = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationPaddingRight", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yy;
        },
        set: function (v) {
            this.i.yy = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationPaddingBottom", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.yw;
        },
        set: function (v) {
            this.i.yw = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "xAxisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.yu;
        },
        set: function (v) {
            this.i.yu = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.abc);
        },
        set: function (v) {
            this.i.abc = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.aba);
        },
        set: function (v) {
            this.i.aba = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationBackgroundCornerRadius", {
        /**
         * Gets or sets the corner radius to use for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.yv;
        },
        set: function (v) {
            this.i.yv = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: function () {
            return this.i.y2;
        },
        set: function (v) {
            this.i.y2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.abb);
        },
        set: function (v) {
            this.i.abb = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "yAxisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.y0;
        },
        set: function (v) {
            this.i.y0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrValueLayer.prototype, "skipUnknownValues", {
        /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
        get: function () {
            return this.i.yl;
        },
        set: function (v) {
            this.i.yl = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrValueLayer.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetSeries && this.targetSeries.name && this.targetSeries.name == name) {
            return this.targetSeries;
        }
        if (this.targetAxis && this.targetAxis.name && this.targetAxis.name == name) {
            return this.targetAxis;
        }
        return null;
    };
    IgrValueLayer.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.targetSeries && this.targetSeries._styling) {
            this.targetSeries._styling(container, component, this);
        }
        if (this.targetAxis && this.targetAxis._styling) {
            this.targetAxis._styling(container, component, this);
        }
        this._inStyling = false;
    };
    return IgrValueLayer;
}(IgrAnnotationLayer));
export { IgrValueLayer };
