import { IgrSizeScale } from "./igr-size-scale";
import { IgrBrushScale } from "./igr-brush-scale";
import { IgrScatterBase, IIgrScatterBaseProps } from "./igr-scatter-base";
import { BubbleSeries } from "./BubbleSeries";
/**
 * Represents a IgxDataChartComponent bubble series.
*/
export declare class IgrBubbleSeries extends IgrScatterBase<IIgrBubbleSeriesProps> {
    protected createImplementation(): BubbleSeries;
    /**
                                 * @hidden
                                 */
    get i(): BubbleSeries;
    constructor(props: IIgrBubbleSeriesProps);
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers(): boolean;
    /**
     * Gets or sets the radius mapping property for the current series object.
    */
    get radiusMemberPath(): string;
    set radiusMemberPath(v: string);
    /**
     * Gets or sets the radius size scale for the bubbles.
    */
    get radiusScale(): IgrSizeScale;
    set radiusScale(v: IgrSizeScale);
    /**
     * Gets or sets the Label mapping property for the current series object.
    */
    get labelMemberPath(): string;
    set labelMemberPath(v: string);
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    get fillMemberPath(): string;
    set fillMemberPath(v: string);
    /**
     * Gets or sets the brush scale for the fill brush of markers.
    */
    get fillScale(): IgrBrushScale;
    set fillScale(v: IgrBrushScale);
    /**
     * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    get fillScaleUseGlobalValues(): boolean;
    set fillScaleUseGlobalValues(v: boolean);
    /**
     * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
     * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
    */
    get markerOutlineUsesFillScale(): boolean;
    set markerOutlineUsesFillScale(v: boolean);
    /**
     * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
     * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
    */
    get markerOutlineBrightness(): number;
    set markerOutlineBrightness(v: number);
    /**
     * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
     * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
    */
    get markerBrushBrightness(): number;
    set markerBrushBrightness(v: number);
    /**
     * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath from multiple series.
     * This setting applies only if multiple series are using the same RadiusScale.
    */
    get radiusScaleUseGlobalValues(): boolean;
    set radiusScaleUseGlobalValues(v: boolean);
    /**
     * Gets or sets the label displayed before series' radius value in the Data Legend.
    */
    get radiusMemberAsLegendLabel(): string;
    set radiusMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the label displayed before series' fill value in the Data Legend.
    */
    get fillMemberAsLegendLabel(): string;
    set fillMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the unit displayed after series' radius value in the Data Legend.
    */
    get radiusMemberAsLegendUnit(): string;
    set radiusMemberAsLegendUnit(v: string);
    /**
     * Gets or sets the unit displayed after series' fill value in the Data Legend.
    */
    get fillMemberAsLegendUnit(): string;
    set fillMemberAsLegendUnit(v: string);
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Gets the value of a requested member path from the series.
    
    * @param memberPathName  * The property name of a valid member path for the series
    */
    getMemberPathValue(memberPathName: string): string;
}
export interface IIgrBubbleSeriesProps extends IIgrScatterBaseProps {
    /**
     * Gets or sets the radius mapping property for the current series object.
    */
    radiusMemberPath?: string;
    /**
     * Gets or sets the radius size scale for the bubbles.
    */
    radiusScale?: IgrSizeScale;
    /**
     * Gets or sets the Label mapping property for the current series object.
    */
    labelMemberPath?: string;
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    fillMemberPath?: string;
    /**
     * Gets or sets the brush scale for the fill brush of markers.
    */
    fillScale?: IgrBrushScale;
    /**
     * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    fillScaleUseGlobalValues?: boolean | string;
    /**
     * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
     * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
    */
    markerOutlineUsesFillScale?: boolean | string;
    /**
     * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
     * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
    */
    markerOutlineBrightness?: number | string;
    /**
     * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
     * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
    */
    markerBrushBrightness?: number | string;
    /**
     * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath from multiple series.
     * This setting applies only if multiple series are using the same RadiusScale.
    */
    radiusScaleUseGlobalValues?: boolean | string;
    /**
     * Gets or sets the label displayed before series' radius value in the Data Legend.
    */
    radiusMemberAsLegendLabel?: string;
    /**
     * Gets or sets the label displayed before series' fill value in the Data Legend.
    */
    fillMemberAsLegendLabel?: string;
    /**
     * Gets or sets the unit displayed after series' radius value in the Data Legend.
    */
    radiusMemberAsLegendUnit?: string;
    /**
     * Gets or sets the unit displayed after series' fill value in the Data Legend.
    */
    fillMemberAsLegendUnit?: string;
}
