import { IgRect } from "igniteui-react-core";
import { IgPoint } from "igniteui-react-core";
import { IgrCategoryAxisBase } from "./igr-category-axis-base";
import { IgrNumericAxisBase } from "./igr-numeric-axis-base";
import { IgrFragmentBase, IIgrFragmentBaseProps } from "./igr-fragment-base";
import { ColumnFragment } from "./ColumnFragment";
/**
 * Represents one part of a StackedColumnSeries.
*/
export declare class IgrColumnFragment<P extends IIgrColumnFragmentProps = IIgrColumnFragmentProps> extends IgrFragmentBase<P> {
    protected createImplementation(): ColumnFragment;
    /**
                                 * @hidden
                                 */
    get i(): ColumnFragment;
    constructor(props: P);
    /**
     * Gets whether the current series shows a column shape.
    */
    get isColumn(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX(): number;
    set radiusX(v: number);
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY(): number;
    set radiusY(v: number);
    /**
     * Gets or sets the effective x-axis for this series.
    */
    get fragmentXAxis(): IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for this series.
    */
    get fragmentYAxis(): IgrNumericAxisBase;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    getItemIndex(world: IgPoint): number;
}
export interface IIgrColumnFragmentProps extends IIgrFragmentBaseProps {
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX?: number | string;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY?: number | string;
}
