import { IgrAnchoredRadialSeries, IIgrAnchoredRadialSeriesProps } from "./igr-anchored-radial-series";
import { RadialColumnSeries } from "./RadialColumnSeries";
/**
 * Represents a IgxDataChartComponent radial column series.
 * Compare values across categories by using radial rectangles.
*/
export declare class IgrRadialColumnSeries extends IgrAnchoredRadialSeries<IIgrRadialColumnSeriesProps> {
    protected createImplementation(): RadialColumnSeries;
    /**
                                 * @hidden
                                 */
    get i(): RadialColumnSeries;
    constructor(props: IIgrRadialColumnSeriesProps);
    /**
     * Gets whether the current series shows a column shape.
    */
    get isColumn(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX(): number;
    set radiusX(v: number);
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY(): number;
    set radiusY(v: number);
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    onApplyTemplate(): void;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
}
export interface IIgrRadialColumnSeriesProps extends IIgrAnchoredRadialSeriesProps {
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX?: number | string;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY?: number | string;
}
